# updateNavMenus.tcl: update the nav-menus of top-level pages
#
# $Id: updateNavMenus.tcl,v 1.9 2001/07/22 21:47:11 johnr Exp $
#
# Copyright (c) 1998-2001 The Regents of the University of California.
# All rights reserved. See the file COPYRIGHT for details.
#


### Assumed global variables:
# debug: print debug information if on
# silent: don't print anything if on

### Variables
#
set navmenuFile [file join doc templates _navmenu.html]
set imagedir "images"

#######################################################################
#### updateNavMenus
#
# Update the navigation menus of the top-level pages -- that is,
# the main index file and the index files at the second level.
# Each file must have a DIV element with the id "navmenu".
#
proc updateNavMenus {DIVA} {
    global debug silent
    global navmenuFile imagedir

    # Read the DIVA variables
    parseMakefile [file join $DIVA mk diva.mk]
    set DOCDIRS [getMakevar DOCDIRS]
    if $debug {
	puts "DOCDIRS = $DOCDIRS"
    }

    # Read the template
    if $debug {
	puts "Reading template from [file join $DIVA $navmenuFile]"
    }
    set fd [open [file join $DIVA $navmenuFile]]
    set navmenu [read $fd]
    close $fd
    if $debug {
	puts "Template is\n$navmenu"
    }

    # Do the root
    set file [file join $DIVA doc index.html]
    if !$silent {
	puts -nonewline $file
    }
    set fd [open $file]
    set text [read $fd]
    close $fd
    set result [substComment text navmenu $navmenu]
    if $result {
	set fd [open $file "w"]
	puts $fd $text
	close $fd
	if !$silent {
	    puts " -- ok"
	}
    } else {
	if !$silent {
	    puts " -- Nav-menu not found"
	}
    }

    # Modify the navmenu text
    regsub -all -nocase "src=\"" $navmenu "src=\"../" navmenu
    regsub -all -nocase "href=\"" $navmenu "href=\"../" navmenu
    regsub -all -nocase "src=\'" $navmenu "src=\'../" navmenu
    regsub -all -nocase "href=\'" $navmenu "href=\'../" navmenu
    if $debug {
	puts "Template is\n$navmenu"
    }
 
    # Do the second-level files
    foreach dir $DOCDIRS {
	set file [file join $DIVA doc $dir index.html]
	if !$silent {
	    puts -nonewline $file
	}
	set fd [open $file]
	set text [read $fd]
	close $fd
	set result [substComment text navmenu $navmenu]
	if $result {
	    set fd [open $file "w"]
	    puts $fd $text
	    close $fd
	    if !$silent {
		puts " -- ok"
	    }
	} else {
	    if !$silent {
		puts " -- Nav-menu not found"
	    }
	}
    }
}








